$set 9 #Window


$ #Creating
# BlackboxWindow::BlackboxWindow: 0x%lx \n
$ #XGetWindowAttributesFail
# BlackboxWindow::BlackboxWindow: XGetWindowAttributres \n
$ #CannotFindScreen
# BlackboxWindow::BlackboxWindow: 롼ȥɥ 0x%lx Ф륹꡼\
ߤĤޤ\n
$ #Unnamed
# ̾ʤ
$ #MapRequest
# BlackboxWindow::mapRequestEvent() (0x%lx Ф)\n
$ #UnmapNotify
# BlackboxWindow::unmapNotifyEvent() (0x%lx Ф)\n
$ #ReparentNotify
# BlackboxWindow::unmapnotifyEvent: reparent 0x%lx to 0x%lx\n
